@@ -38,9 +38,15 @@
 #define KONOHA_VERSION   PACKAGE_VERSION
 #else
 #define KONOHA_NAME     "konoha"
-#define KONOHA_VERSION  "0.1.5.1"
+#define KONOHA_VERSION  "0.1.8"
 #endif
 
+#define KONOHA_URL		"http://konoha.sourceforge.jp/"
+#define KONOHA_URLBASE  "kttp://konoha.sourceforge.jp/wiki/"
+
+#define KONOHA_BUILDID_TOOOLD  360
+#define KNH_CHECK_VERSION(id)  ((id) <= KONOHA_BUILDID_TOOOLD)
+
 /* ======================================================================== */
 
 #ifdef KONOHA_OS__LINUX
@@ -122,7 +128,6 @@
 #define KONOHA_CC_VERSION "UNKNOWN COMPILER"
 #endif
 
-
 /* ======================================================================== */
 /* [DEFUALT] */
 
